@@ -51,7 +51,6 @@
 #include "gsm-sound.h"
 #include "gsm-gsd.h"
 #include "gsm-keyring.h"
-#include "gsm-xrandr.h"
 #include "gsm-at-startup.h"
 #include "gsm-remote-desktop.h"
 
@@ -184,6 +183,29 @@ gsm_check_for_root (void)
   return !(response == ROOTSESSION_RESPONSE_CONTINUE);
 }
 
+static void
+gsm_breakpad_set_gtk_modules (void)
+{
+  gchar *path;
+  const gchar *old_env;
+  gchar *new_env;
+
+  path = g_find_program_in_path ("bug-buddy");
+  if (!path)
+    return;
+
+  g_free (path);
+
+  old_env = g_getenv ("GTK_MODULES");
+  if (old_env)
+    new_env = g_strconcat (old_env, ":gnomebreakpad", NULL);
+  else
+    new_env = g_strdup ("gnomebreakpad");
+  
+  g_setenv ("GTK_MODULES", new_env, TRUE);
+  g_free (new_env);
+}
+
 #define FALLBACK_TIME_UTILITY "time-admin"
 #define CLOCKSESSION_RESPONSE_IGNORE 1
 #define CLOCKSESSION_RESPONSE_ADJUST 3
@@ -591,7 +613,8 @@ main (int argc, char *argv[])
   GConfClient *gconf_client;
   GOptionContext *goption_context;
   gboolean dbus_daemon_owner;
-  
+  GnomeProgram *program;
+
   if (g_getenv ("GSM_VERBOSE_DEBUG"))
     gsm_set_verbose (TRUE);
 
@@ -628,9 +651,6 @@ main (int argc, char *argv[])
   if (gsm_check_for_root ())
     return 0;
 
-  /* We need to do this as early as possible */
-  gsm_set_display_properties ();
-  
   if (ORBit_proto_use ("IPv4") || ORBit_proto_use ("IPv6"))
     gnome_login_check ();
 
@@ -652,6 +672,8 @@ main (int argc, char *argv[])
         }
     }
   
+  gsm_breakpad_set_gtk_modules ();
+
   /* Read the config option early, so that we know if a11y is set or not */ 
   gconf_client = gsm_get_conf_client ();
   gconf_client_add_dir (gconf_client, GSM_GCONF_CONFIG_PREFIX, GCONF_CLIENT_PRELOAD_ONELEVEL, NULL); 
@@ -672,9 +694,10 @@ main (int argc, char *argv[])
   g_option_context_set_translation_domain (goption_context, GETTEXT_PACKAGE);
   g_option_context_add_main_entries (goption_context, options, GETTEXT_PACKAGE);
 
-  gnome_program_init("gnome-session", VERSION, LIBGNOMEUI_MODULE, argc, argv, 
-		  GNOME_PARAM_GOPTION_CONTEXT, goption_context,
-		  NULL);
+  program = gnome_program_init ("gnome-session", VERSION, LIBGNOMEUI_MODULE,
+                                argc, argv,
+                                GNOME_PARAM_GOPTION_CONTEXT, goption_context,
+                                NULL);
 
  /* FIXME: it would be nice to skip this check if we're debugging the
  session manager. */
@@ -753,8 +776,6 @@ main (int argc, char *argv[])
   g_setenv ("GNOME_DESKTOP_SESSION_ID", session_name, TRUE);
   the_session = read_session (session_name);
 
-  gsm_sound_login ();
-
   gsm_remote_desktop_start ();
 
   if (splashing)
@@ -780,5 +801,7 @@ main (int argc, char *argv[])
 
   g_free (session_name);
 
+  g_object_unref (program);
+
   return 0;
 }
